@@ -83,55 +83,55 @@ Vytvářím tmp soubor.</translation>
     </message>
     <message>
         <source>You don&apos;t remember this card yet.</source>
-        <translation>Tuto kartu jste si zatím nezapamatoval(a).</translation>
+        <translation type="unfinished">Tuto kartu jste si zatím nezapamatoval(a).</translation>
     </message>
     <message>
         <source>Like &apos;0&apos;, but it&apos;s getting more familiar.</source>
-        <translation>Jako &apos;0&apos;, ale už vám to připadá povědomé.</translation>
+        <translation type="unfinished">Jako &apos;0&apos;, ale už vám to připadá povědomé.</translation>
     </message>
     <message>
         <source> Show it less often.</source>
-        <translation>Neukazovat tak často.</translation>
+        <translation type="unfinished">Neukazovat tak často.</translation>
     </message>
     <message>
         <source>You&apos;ve memorised this card now,</source>
-        <translation>Tuto kartu jste si právě zapamatoval(a)</translation>
+        <translation type="unfinished">Tuto kartu jste si právě zapamatoval(a)</translation>
     </message>
     <message>
         <source> and will probably remember it for a few days.</source>
-        <translation> a pravděpodobně si ji několik dnů budete pamatovat.</translation>
+        <translation type="unfinished"> a pravděpodobně si ji několik dnů budete pamatovat.</translation>
     </message>
     <message>
         <source>You have forgotten this card completely.</source>
-        <translation>Tuto kartu jste kompletně zapomněl(a).</translation>
+        <translation type="unfinished">Tuto kartu jste kompletně zapomněl(a).</translation>
     </message>
     <message>
         <source>Barely correct answer. The interval was way too long.</source>
-        <translation>Téměř správná odpověď. Interval byl příliš dlouhý.</translation>
+        <translation type="unfinished">Téměř správná odpověď. Interval byl příliš dlouhý.</translation>
     </message>
     <message>
         <source>Correct answer, but with much effort.</source>
-        <translation>Správná odpověď, ale s velkým úsilím.</translation>
+        <translation type="unfinished">Správná odpověď, ale s velkým úsilím.</translation>
     </message>
     <message>
         <source> The interval was probably too long.</source>
-        <translation> Interval byl pravděpodobně moc dlouhý.</translation>
+        <translation type="unfinished"> Interval byl pravděpodobně moc dlouhý.</translation>
     </message>
     <message>
         <source>Correct answer, with some effort.</source>
-        <translation>Správná odpověď, i když s určitým úsilím.</translation>
+        <translation type="unfinished">Správná odpověď, i když s určitým úsilím.</translation>
     </message>
     <message>
         <source> The interval was probably just right.</source>
-        <translation> Interval byl pravděpodobně odpovídající.</translation>
+        <translation type="unfinished"> Interval byl pravděpodobně odpovídající.</translation>
     </message>
     <message>
         <source>Correct answer, but without any</source>
-        <translation>Správná odpověď bez jakýchkoliv</translation>
+        <translation type="unfinished">Správná odpověď bez jakýchkoliv</translation>
     </message>
     <message>
         <source> difficulties. The interval was probably too short.</source>
-        <translation> potíží. Interval byl pravděpodobně moc krátký.</translation>
+        <translation type="unfinished"> potíží. Interval byl pravděpodobně moc krátký.</translation>
     </message>
 </context>
 <context>
@@ -867,63 +867,63 @@ takže by jste potom měl(a) provést </translation>
     <name>MainDlg</name>
     <message>
         <source>Mnemosyne databases (*.mem)</source>
-        <translation>Mnemosyne databáze (*.mem)</translation>
+        <translation type="unfinished">Mnemosyne databáze (*.mem)</translation>
     </message>
     <message>
         <source>New</source>
-        <translation>Nová</translation>
+        <translation type="unfinished">Nová</translation>
     </message>
     <message>
         <source>Please wait...</source>
-        <translation>Čekejte prosím...</translation>
+        <translation type="unfinished">Čekejte prosím...</translation>
     </message>
     <message>
         <source>Mnemosyne</source>
-        <translation>Mnemosyne</translation>
+        <translation type="unfinished">Mnemosyne</translation>
     </message>
     <message>
         <source>Delete current card?</source>
-        <translation>Smazat tuto kartu?</translation>
+        <translation type="unfinished">Smazat tuto kartu?</translation>
     </message>
     <message>
         <source>&amp;Yes</source>
-        <translation>&amp;Ano</translation>
+        <translation type="unfinished">&amp;Ano</translation>
     </message>
     <message>
         <source>&amp;No</source>
-        <translation>&amp;Ne</translation>
+        <translation type="unfinished">&amp;Ne</translation>
     </message>
     <message>
         <source>Returns in </source>
-        <translation>Ukáže se za </translation>
+        <translation type="unfinished">Ukáže se za </translation>
     </message>
     <message>
         <source> day(s).</source>
-        <translation> dnů.</translation>
+        <translation type="unfinished"> dnů.</translation>
     </message>
     <message>
         <source>Next repetition: today.</source>
-        <translation>Další opakování: dnes.</translation>
+        <translation type="unfinished">Další opakování: dnes.</translation>
     </message>
     <message>
         <source>Next repetition: tomorrow.</source>
-        <translation>Další opakování: zítra.</translation>
+        <translation type="unfinished">Další opakování: zítra.</translation>
     </message>
     <message>
         <source>Next repetition in </source>
-        <translation>Další opakování za </translation>
+        <translation type="unfinished">Další opakování za </translation>
     </message>
     <message>
         <source> days.</source>
-        <translation> dnů.</translation>
+        <translation type="unfinished"> dnů.</translation>
     </message>
     <message>
         <source>Question:</source>
-        <translation>Otázka:</translation>
+        <translation type="unfinished">Otázka:</translation>
     </message>
     <message>
         <source>&lt;default&gt;</source>
-        <translation>&lt;default&gt;</translation>
+        <translation type="unfinished">&lt;default&gt;</translation>
     </message>
     <message>
         <source>Show &amp;answer</source>
@@ -931,31 +931,31 @@ takže by jste potom měl(a) provést </translation>
     </message>
     <message>
         <source>Learn ahead of schedule</source>
-        <translation>Učit se navíc</translation>
+        <translation type="unfinished">Učit se navíc</translation>
     </message>
     <message>
         <source>Pick days until next repetition:</source>
-        <translation>Vyberte počet dnů do dalšího opakování:</translation>
+        <translation type="unfinished">Vyberte počet dnů do dalšího opakování:</translation>
     </message>
     <message>
         <source>Grade your answer:</source>
-        <translation>Ohodnoťte svou odpověď:</translation>
+        <translation type="unfinished">Ohodnoťte svou odpověď:</translation>
     </message>
     <message>
         <source>Scheduled: </source>
-        <translation>Naplánovaných: </translation>
+        <translation type="unfinished">Naplánovaných: </translation>
     </message>
     <message>
         <source>Not memorised: </source>
-        <translation>Nezapamatovaných: </translation>
+        <translation type="unfinished">Nezapamatovaných: </translation>
     </message>
     <message>
         <source>All: </source>
-        <translation>Všech: </translation>
+        <translation type="unfinished">Všech: </translation>
     </message>
     <message>
         <source>Show answer</source>
-        <translation>Ukázat odpověď</translation>
+        <translation type="unfinished">Ukázat odpověď</translation>
     </message>
 </context>
 <context>
