@@ -85,55 +85,55 @@ Opretter tmp fil.</translation>
     </message>
     <message>
         <source>You don&apos;t remember this card yet.</source>
-        <translation>Du kan ikke huske dette kort endnu.</translation>
+        <translation type="unfinished">Du kan ikke huske dette kort endnu.</translation>
     </message>
     <message>
         <source>Like &apos;0&apos;, but it&apos;s getting more familiar.</source>
-        <translation>Som &apos;0&apos;, men det er ved at blive genkendeligt.</translation>
+        <translation type="unfinished">Som &apos;0&apos;, men det er ved at blive genkendeligt.</translation>
     </message>
     <message>
         <source> Show it less often.</source>
-        <translation>Vis det sjældnere.</translation>
+        <translation type="unfinished">Vis det sjældnere.</translation>
     </message>
     <message>
         <source>You&apos;ve memorised this card now,</source>
-        <translation>Du husker dette kort nu,</translation>
+        <translation type="unfinished">Du husker dette kort nu,</translation>
     </message>
     <message>
         <source> and will probably remember it for a few days.</source>
-        <translation>og vil nok huske det et par dage.</translation>
+        <translation type="unfinished">og vil nok huske det et par dage.</translation>
     </message>
     <message>
         <source>You have forgotten this card completely.</source>
-        <translation>Du har fuldstændig glemt dette kort.</translation>
+        <translation type="unfinished">Du har fuldstændig glemt dette kort.</translation>
     </message>
     <message>
         <source>Barely correct answer. The interval was way too long.</source>
-        <translation>Langt fra korrekt svar. Intervallet var alt for langt.</translation>
+        <translation type="unfinished">Langt fra korrekt svar. Intervallet var alt for langt.</translation>
     </message>
     <message>
         <source>Correct answer, but with much effort.</source>
-        <translation>Rigtigt svar, men med meget besvær.</translation>
+        <translation type="unfinished">Rigtigt svar, men med meget besvær.</translation>
     </message>
     <message>
         <source> The interval was probably too long.</source>
-        <translation>Intervallet var nok lidt for langt.</translation>
+        <translation type="unfinished">Intervallet var nok lidt for langt.</translation>
     </message>
     <message>
         <source>Correct answer, with some effort.</source>
-        <translation>Rigtigt svar, men med noget besvær.</translation>
+        <translation type="unfinished">Rigtigt svar, men med noget besvær.</translation>
     </message>
     <message>
         <source> The interval was probably just right.</source>
-        <translation>Intervallet var nok rigtigt.</translation>
+        <translation type="unfinished">Intervallet var nok rigtigt.</translation>
     </message>
     <message>
         <source>Correct answer, but without any</source>
-        <translation>Rigtigt svar, men uden noget</translation>
+        <translation type="unfinished">Rigtigt svar, men uden noget</translation>
     </message>
     <message>
         <source> difficulties. The interval was probably too short.</source>
-        <translation>besvær. Intervallet var nok lidt for kort.</translation>
+        <translation type="unfinished">besvær. Intervallet var nok lidt for kort.</translation>
     </message>
 </context>
 <context>
@@ -854,91 +854,91 @@ så du vil sikkert gerne køre</translation>
     <name>MainDlg</name>
     <message>
         <source>Mnemosyne databases (*.mem)</source>
-        <translation>Mnemosyne databaser (*.mem)</translation>
+        <translation type="unfinished">Mnemosyne databaser (*.mem)</translation>
     </message>
     <message>
         <source>New</source>
-        <translation>Ny</translation>
+        <translation type="unfinished">Ny</translation>
     </message>
     <message>
         <source>Please wait...</source>
-        <translation>Vent venligst...</translation>
+        <translation type="unfinished">Vent venligst...</translation>
     </message>
     <message>
         <source>Mnemosyne</source>
-        <translation>Mnemosyne</translation>
+        <translation type="unfinished">Mnemosyne</translation>
     </message>
     <message>
         <source>Delete current card?</source>
-        <translation>Slet dette kort?</translation>
+        <translation type="unfinished">Slet dette kort?</translation>
     </message>
     <message>
         <source>&amp;Yes</source>
-        <translation>&amp;Ja</translation>
+        <translation type="unfinished">&amp;Ja</translation>
     </message>
     <message>
         <source>&amp;No</source>
-        <translation>&amp;Nej</translation>
+        <translation type="unfinished">&amp;Nej</translation>
     </message>
     <message>
         <source>Returns in </source>
-        <translation>Vender tilbage om </translation>
+        <translation type="unfinished">Vender tilbage om </translation>
     </message>
     <message>
         <source> day(s).</source>
-        <translation> dag(e).</translation>
+        <translation type="unfinished"> dag(e).</translation>
     </message>
     <message>
         <source>Next repetition: today.</source>
-        <translation>Næste repetition: i dag.</translation>
+        <translation type="unfinished">Næste repetition: i dag.</translation>
     </message>
     <message>
         <source>Next repetition: tomorrow.</source>
-        <translation>Næste repetition: i morgen.</translation>
+        <translation type="unfinished">Næste repetition: i morgen.</translation>
     </message>
     <message>
         <source>Next repetition in </source>
-        <translation>Næste repetition om </translation>
+        <translation type="unfinished">Næste repetition om </translation>
     </message>
     <message>
         <source> days.</source>
-        <translation> dage.</translation>
+        <translation type="unfinished"> dage.</translation>
     </message>
     <message>
         <source>Question:</source>
-        <translation>Spørgsmål:</translation>
+        <translation type="unfinished">Spørgsmål:</translation>
     </message>
     <message>
         <source>&lt;default&gt;</source>
-        <translation>&lt;standard&gt;</translation>
+        <translation type="unfinished">&lt;standard&gt;</translation>
     </message>
     <message>
         <source>Show answer</source>
-        <translation>Vis svar</translation>
+        <translation type="unfinished">Vis svar</translation>
     </message>
     <message>
         <source>Learn ahead of schedule</source>
-        <translation>Lær forud for skema</translation>
+        <translation type="unfinished">Lær forud for skema</translation>
     </message>
     <message>
         <source>Pick days until next repetition:</source>
-        <translation>Vælg antal dage før næste repetition:</translation>
+        <translation type="unfinished">Vælg antal dage før næste repetition:</translation>
     </message>
     <message>
         <source>Grade your answer:</source>
-        <translation>Angiv grad for dit svar:</translation>
+        <translation type="unfinished">Angiv grad for dit svar:</translation>
     </message>
     <message>
         <source>Scheduled: </source>
-        <translation>Planlagt: </translation>
+        <translation type="unfinished">Planlagt: </translation>
     </message>
     <message>
         <source>Not memorised: </source>
-        <translation>Ikke memoriseret: </translation>
+        <translation type="unfinished">Ikke memoriseret: </translation>
     </message>
     <message>
         <source>All: </source>
-        <translation>Alle: </translation>
+        <translation type="unfinished">Alle: </translation>
     </message>
 </context>
 <context>
