@@ -3,35 +3,35 @@
     <name></name>
     <message>
         <source>Mnemosyne</source>
-        <translation type="unfinished">Mnemosyne</translation>
+        <translation>Mnemosyne</translation>
     </message>
     <message>
         <source>Removed duplicates: </source>
-        <translation type="unfinished">Entfernte Duplikate: </translation>
+        <translation>Entfernte Duplikate: </translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation type="unfinished">&amp;OK</translation>
+        <translation>&amp;OK</translation>
     </message>
     <message>
         <source>There are cards with different answers for question:
 
 </source>
-        <translation type="unfinished">Es gibt Karten mit verschiedene Antworten für die Frage:
+        <translation>Es gibt Karten mit verschiedene Antworten für die Frage:
 
 </translation>
     </message>
     <message>
         <source>&amp;Merge and edit</source>
-        <translation type="unfinished">&amp;Zusammenfassen und bearbeiten</translation>
+        <translation>&amp;Zusammenfassen und bearbeiten</translation>
     </message>
     <message>
         <source>&amp;Don&apos;t merge</source>
-        <translation type="unfinished">&amp;Nicht zusammenfassen</translation>
+        <translation>&amp;Nicht zusammenfassen</translation>
     </message>
     <message>
         <source>Done!</source>
-        <translation type="unfinished">Fertig!</translation>
+        <translation>Fertig!</translation>
     </message>
     <message>
         <source>Like &apos;0&apos;, but it&apos;s getting more familiar.</source>
@@ -43,53 +43,53 @@
     </message>
     <message>
         <source>Error in config.py:</source>
-        <translation type="unfinished">Fehler in config.py:</translation>
+        <translation>Fehler in config.py:</translation>
     </message>
     <message>
         <source>Error when running plugin:</source>
-        <translation type="unfinished">Fehler beim Ausführen des Plugin:</translation>
+        <translation>Fehler beim Ausführen des Plugin:</translation>
     </message>
     <message>
         <source>Unable to load file.</source>
-        <translation type="unfinished">Konnte die Datei nicht laden.</translation>
+        <translation>Konnte die Datei nicht laden.</translation>
     </message>
     <message>
         <source>Invalid file format.</source>
-        <translation type="unfinished">Fasches Dateiformat.</translation>
+        <translation>Fasches Dateiformat.</translation>
     </message>
     <message>
         <source>Unable to save file.</source>
-        <translation type="unfinished">Konnte die Datei nicht speichern.</translation>
+        <translation>Konnte die Datei nicht speichern.</translation>
     </message>
     <message>
         <source>Unable to parse XML:</source>
-        <translation type="unfinished">Konnte XML nicht parsen:</translation>
+        <translation>Konnte XML nicht parsen:</translation>
     </message>
     <message>
         <source>Unrecognised encoding.</source>
-        <translation type="unfinished">Unbekannte Kodierung.</translation>
+        <translation>Unbekannte Kodierung.</translation>
     </message>
     <message>
         <source>Missing answer on line:</source>
-        <translation type="unfinished">Fehlende Antwort in Zeile:</translation>
+        <translation>Fehlende Antwort in Zeile:</translation>
     </message>
     <message>
         <source>Unable to load database.
 Creating tmp file.</source>
-        <translation type="unfinished">Konnte die Datenbank nicht laden.
+        <translation>Konnte die Datenbank nicht laden.
 Erstelle temporäre Datei.</translation>
     </message>
     <message>
         <source>File exists:</source>
-        <translation type="unfinished">Vorhandene Datei:</translation>
+        <translation>Vorhandene Datei:</translation>
     </message>
     <message>
         <source>&amp;Overwrite</source>
-        <translation type="unfinished">&amp;Überschreiben</translation>
+        <translation>&amp;Überschreiben</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation type="unfinished">&amp;Abbrechen</translation>
+        <translation>&amp;Abbrechen</translation>
     </message>
     <message>
         <source>You don&apos;t remember this card yet.</source>
@@ -159,7 +159,8 @@ Erstelle temporäre Datei.</translation>
     <message>
         <source>More info: http://mnemosyne-proj.org
 </source>
-        <translation type="unfinished"></translation>
+        <translation>Mehr Informationen unter: http://mnemosyne-proj.org
+</translation>
     </message>
 </context>
 <context>
@@ -405,7 +406,7 @@ Erstelle temporäre Datei.</translation>
     </message>
     <message>
         <source>Preview</source>
-        <translation type="unfinished"></translation>
+        <translation>Vorschau</translation>
     </message>
 </context>
 <context>
@@ -443,7 +444,7 @@ Erstelle temporäre Datei.</translation>
     </message>
     <message>
         <source>Hover with the mouse over the buttons to get extra information.</source>
-        <translation>Für weitergehende Informationen fahre mit der Maus über die Buttons.</translation>
+        <translation>Für weitergehende Informationen, fahre mit der Maus über die Buttons.</translation>
     </message>
     <message>
         <source>Appearance</source>
@@ -527,11 +528,11 @@ Erstelle temporäre Datei.</translation>
     </message>
     <message>
         <source>Learn new cards in random order</source>
-        <translation type="unfinished"></translation>
+        <translation>Neue Karten in zufälliger Reihenfolge lernen</translation>
     </message>
     <message>
         <source>Number of grade 0 cards to hold in your hand:</source>
-        <translation type="unfinished"></translation>
+        <translation>Anzahl der Karten mit der Bewertung 0 im aktuellen Stapel:</translation>
     </message>
 </context>
 <context>
@@ -713,10 +714,6 @@ Vielleicht möchtest Du </translation>
         <source>Add &amp;vice versa</source>
         <translation>Ver&amp;tauscht hinzufügen</translation>
     </message>
-    <message>
-        <source>Alt+F</source>
-        <translation type="obsolete"></translation>
-    </message>
 </context>
 <context>
     <name>EditItemsFrm</name>
@@ -754,7 +751,7 @@ Vielleicht möchtest Du </translation>
     </message>
     <message>
         <source>Alt+F</source>
-        <translation type="unfinished"></translation>
+        <translation>Alt+F</translation>
     </message>
 </context>
 <context>
@@ -873,55 +870,55 @@ Vielleicht möchtest Du </translation>
     <name>MainDlg</name>
     <message>
         <source>Mnemosyne databases (*.mem)</source>
-        <translation>Mnemosyne Datenbanken (*.mem)</translation>
+        <translation type="unfinished">Mnemosyne Datenbanken (*.mem)</translation>
     </message>
     <message>
         <source>Please wait...</source>
-        <translation>Bitte warten...</translation>
+        <translation type="unfinished">Bitte warten...</translation>
     </message>
     <message>
         <source>Mnemosyne</source>
-        <translation>Mnemosyne</translation>
+        <translation type="unfinished">Mnemosyne</translation>
     </message>
     <message>
         <source>Delete current card?</source>
-        <translation>Aktuelle Karte löschen?</translation>
+        <translation type="unfinished">Aktuelle Karte löschen?</translation>
     </message>
     <message>
         <source>&amp;Yes</source>
-        <translation>&amp;Ja</translation>
+        <translation type="unfinished">&amp;Ja</translation>
     </message>
     <message>
         <source>&amp;No</source>
-        <translation>&amp;Nein</translation>
+        <translation type="unfinished">&amp;Nein</translation>
     </message>
     <message>
         <source>Returns in </source>
-        <translation>Kommt wieder in </translation>
+        <translation type="unfinished">Kommt wieder in </translation>
     </message>
     <message>
         <source> day(s).</source>
-        <translation> Tag(en).</translation>
+        <translation type="unfinished"> Tag(en).</translation>
     </message>
     <message>
         <source>Next repetition: today.</source>
-        <translation>Nächste Wiederholung: heute.</translation>
+        <translation type="unfinished">Nächste Wiederholung: heute.</translation>
     </message>
     <message>
         <source>Next repetition: tomorrow.</source>
-        <translation>Nächste Wiederholung: morgen.</translation>
+        <translation type="unfinished">Nächste Wiederholung: morgen.</translation>
     </message>
     <message>
         <source>Next repetition in </source>
-        <translation>Nächste Wiederholung in </translation>
+        <translation type="unfinished">Nächste Wiederholung in </translation>
     </message>
     <message>
         <source>Question:</source>
-        <translation>Frage:</translation>
+        <translation type="unfinished">Frage:</translation>
     </message>
     <message>
         <source>&lt;default&gt;</source>
-        <translation>&lt;Standard&gt;</translation>
+        <translation type="unfinished">&lt;Standard&gt;</translation>
     </message>
     <message>
         <source>Show &amp;answer</source>
@@ -929,35 +926,35 @@ Vielleicht möchtest Du </translation>
     </message>
     <message>
         <source>Learn ahead of schedule</source>
-        <translation>Ohne Rücksicht auf den Zeitplan weiterlernen</translation>
+        <translation type="unfinished">Ohne Rücksicht auf den Zeitplan weiterlernen</translation>
     </message>
     <message>
         <source>Pick days until next repetition:</source>
-        <translation>Wähle die Tage bis zur nächsten Wiederholung:</translation>
+        <translation type="unfinished">Wähle die Tage bis zur nächsten Wiederholung:</translation>
     </message>
     <message>
         <source>Grade your answer:</source>
-        <translation>Bewerte deine Antwort:</translation>
+        <translation type="unfinished">Bewerte deine Antwort:</translation>
     </message>
     <message>
         <source>Scheduled: </source>
-        <translation>Vorgemerkt: </translation>
+        <translation type="unfinished">Vorgemerkt: </translation>
     </message>
     <message>
         <source>Not memorised: </source>
-        <translation>Nicht gelernte: </translation>
+        <translation type="unfinished">Nicht gelernte: </translation>
     </message>
     <message>
         <source>All: </source>
-        <translation>Alle: </translation>
+        <translation type="unfinished">Alle: </translation>
     </message>
     <message>
         <source>New</source>
-        <translation>Neu</translation>
+        <translation type="unfinished">Neu</translation>
     </message>
     <message>
         <source> days.</source>
-        <translation> Tage.</translation>
+        <translation type="unfinished"> Tage.</translation>
     </message>
     <message>
         <source>Show answer</source>
@@ -1479,37 +1476,39 @@ Viel Spass und Erfolg!</translation>
     </message>
     <message>
         <source>No current card.</source>
-        <translation type="unfinished"></translation>
+        <translation>Keine Karten ausgewählt.</translation>
     </message>
     <message>
         <source>Grade:</source>
-        <translation type="unfinished">Bewertung:</translation>
+        <translation>Bewertung:</translation>
     </message>
     <message>
         <source>Easiness:</source>
-        <translation type="unfinished">Leichtigkeit:</translation>
+        <translation>Leichtigkeit:</translation>
     </message>
     <message>
         <source>Repetitions:</source>
-        <translation type="unfinished">Wiederholungen:</translation>
+        <translation>Wiederholungen:</translation>
     </message>
     <message>
         <source>Lapses:</source>
-        <translation type="unfinished">Fehler:</translation>
+        <translation>Fehler:</translation>
     </message>
     <message>
         <source>Days since last repetition:</source>
-        <translation type="unfinished">Tage seit der letzten Wiederholung:</translation>
+        <translation>Tage seit der letzten Wiederholung:</translation>
     </message>
     <message>
         <source>Days until next repetition:</source>
-        <translation type="unfinished">Tage bis zur nächsten Wiederholung:</translation>
+        <translation>Tage bis zur nächsten Wiederholung:</translation>
     </message>
     <message>
         <source>Scheduled cards for next week:
 
 </source>
-        <translation type="unfinished"></translation>
+        <translation>Eingeplante Karten für die nächste Woche:
+
+</translation>
     </message>
 </context>
 <context>
@@ -1544,7 +1543,7 @@ Viel Spass und Erfolg!</translation>
     </message>
     <message>
         <source>Current card</source>
-        <translation type="unfinished"></translation>
+        <translation>Aktuelle Karte</translation>
     </message>
 </context>
 <context>
