@@ -85,55 +85,55 @@ Mnemozino nun kreas tmp-dosieron.</translation>
     </message>
     <message>
         <source>You don&apos;t remember this card yet.</source>
-        <translation>Vi ne jam scias la respondon al ĉi tiu karto.</translation>
+        <translation type="unfinished">Vi ne jam scias la respondon al ĉi tiu karto.</translation>
     </message>
     <message>
         <source>Like &apos;0&apos;, but it&apos;s getting more familiar.</source>
-        <translation>Simila al 0, sed vi plikonadas ĝin.</translation>
+        <translation type="unfinished">Simila al 0, sed vi plikonadas ĝin.</translation>
     </message>
     <message>
         <source> Show it less often.</source>
-        <translation>Montru ĝin pli malofte.</translation>
+        <translation type="unfinished">Montru ĝin pli malofte.</translation>
     </message>
     <message>
         <source>You&apos;ve memorised this card now,</source>
-        <translation>Nun vi scias tiun karton,</translation>
+        <translation type="unfinished">Nun vi scias tiun karton,</translation>
     </message>
     <message>
         <source> and will probably remember it for a few days.</source>
-        <translation>kaj probable vi memoros ĝin dum kelkaj tagoj.</translation>
+        <translation type="unfinished">kaj probable vi memoros ĝin dum kelkaj tagoj.</translation>
     </message>
     <message>
         <source>You have forgotten this card completely.</source>
-        <translation>Vi tute forgesis ĉi tiun karton.</translation>
+        <translation type="unfinished">Vi tute forgesis ĉi tiun karton.</translation>
     </message>
     <message>
         <source>Barely correct answer. The interval was way too long.</source>
-        <translation>Via apenaŭ memoris la respondon; la intertempo estis multe tro longa.</translation>
+        <translation type="unfinished">Via apenaŭ memoris la respondon; la intertempo estis multe tro longa.</translation>
     </message>
     <message>
         <source>Correct answer, but with much effort.</source>
-        <translation>Vi memoris la ĝustan respondon, sed per multa peno.</translation>
+        <translation type="unfinished">Vi memoris la ĝustan respondon, sed per multa peno.</translation>
     </message>
     <message>
         <source> The interval was probably too long.</source>
-        <translation>La intertempo probable estis tro longa.</translation>
+        <translation type="unfinished">La intertempo probable estis tro longa.</translation>
     </message>
     <message>
         <source>Correct answer, with some effort.</source>
-        <translation>Vi memoris la ĝustan respondo per iom da peno.</translation>
+        <translation type="unfinished">Vi memoris la ĝustan respondo per iom da peno.</translation>
     </message>
     <message>
         <source> The interval was probably just right.</source>
-        <translation>La intertempo probable estis ĝusta.</translation>
+        <translation type="unfinished">La intertempo probable estis ĝusta.</translation>
     </message>
     <message>
         <source>Correct answer, but without any</source>
-        <translation>Vi sciis la ĝustan respondon, sed sen ia</translation>
+        <translation type="unfinished">Vi sciis la ĝustan respondon, sed sen ia</translation>
     </message>
     <message>
         <source> difficulties. The interval was probably too short.</source>
-        <translation> malfacilo. La intertempo probable estis tro mallonga.</translation>
+        <translation type="unfinished"> malfacilo. La intertempo probable estis tro mallonga.</translation>
     </message>
 </context>
 <context>
@@ -856,91 +856,91 @@ vi devus forigi duoblojn</translation>
     <name>MainDlg</name>
     <message>
         <source>Mnemosyne databases (*.mem)</source>
-        <translation>Mnemozinaj datumbazoj (*.mem)</translation>
+        <translation type="unfinished">Mnemozinaj datumbazoj (*.mem)</translation>
     </message>
     <message>
         <source>New</source>
-        <translation>Novan</translation>
+        <translation type="unfinished">Novan</translation>
     </message>
     <message>
         <source>Please wait...</source>
-        <translation>Bonvolu atendi . . .</translation>
+        <translation type="unfinished">Bonvolu atendi . . .</translation>
     </message>
     <message>
         <source>Mnemosyne</source>
-        <translation>Mnemozino</translation>
+        <translation type="unfinished">Mnemozino</translation>
     </message>
     <message>
         <source>Delete current card?</source>
-        <translation>Ĉu vi volas forviŝi tiun karton?</translation>
+        <translation type="unfinished">Ĉu vi volas forviŝi tiun karton?</translation>
     </message>
     <message>
         <source>&amp;Yes</source>
-        <translation>&amp;Jes</translation>
+        <translation type="unfinished">&amp;Jes</translation>
     </message>
     <message>
         <source>&amp;No</source>
-        <translation>&amp;Ne</translation>
+        <translation type="unfinished">&amp;Ne</translation>
     </message>
     <message>
         <source>Returns in </source>
-        <translation>Ĉi tiu karto reaperos post </translation>
+        <translation type="unfinished">Ĉi tiu karto reaperos post </translation>
     </message>
     <message>
         <source> day(s).</source>
-        <translation> tagoj.</translation>
+        <translation type="unfinished"> tagoj.</translation>
     </message>
     <message>
         <source>Next repetition: today.</source>
-        <translation>Sekva ripeto: hodiaŭ</translation>
+        <translation type="unfinished">Sekva ripeto: hodiaŭ</translation>
     </message>
     <message>
         <source>Next repetition: tomorrow.</source>
-        <translation>Sekva ripeto: morgau</translation>
+        <translation type="unfinished">Sekva ripeto: morgau</translation>
     </message>
     <message>
         <source>Next repetition in </source>
-        <translation>Sekva ripetado post </translation>
+        <translation type="unfinished">Sekva ripetado post </translation>
     </message>
     <message>
         <source> days.</source>
-        <translation> tagoj</translation>
+        <translation type="unfinished"> tagoj</translation>
     </message>
     <message>
         <source>Question:</source>
-        <translation>Demando:</translation>
+        <translation type="unfinished">Demando:</translation>
     </message>
     <message>
         <source>&lt;default&gt;</source>
-        <translation>Defaŭlto</translation>
+        <translation type="unfinished">Defaŭlto</translation>
     </message>
     <message>
         <source>Show answer</source>
-        <translation>Vidi respondon</translation>
+        <translation type="unfinished">Vidi respondon</translation>
     </message>
     <message>
         <source>Learn ahead of schedule</source>
-        <translation>Antaŭlerni</translation>
+        <translation type="unfinished">Antaŭlerni</translation>
     </message>
     <message>
         <source>Pick days until next repetition:</source>
-        <translation>Elekti tagojn antaŭ la sekva ripeto:</translation>
+        <translation type="unfinished">Elekti tagojn antaŭ la sekva ripeto:</translation>
     </message>
     <message>
         <source>Grade your answer:</source>
-        <translation>Rangigi vian respondon:</translation>
+        <translation type="unfinished">Rangigi vian respondon:</translation>
     </message>
     <message>
         <source>Scheduled: </source>
-        <translation>Planataj: </translation>
+        <translation type="unfinished">Planataj: </translation>
     </message>
     <message>
         <source>Not memorised: </source>
-        <translation>Nekonataj: </translation>
+        <translation type="unfinished">Nekonataj: </translation>
     </message>
     <message>
         <source>All: </source>
-        <translation>Ĉiuj: </translation>
+        <translation type="unfinished">Ĉiuj: </translation>
     </message>
 </context>
 <context>
