@@ -871,55 +871,55 @@ Tal vez desee ejecutar </translation>
     <name>MainDlg</name>
     <message>
         <source>Mnemosyne databases (*.mem)</source>
-        <translation>Bases de datos Mnemosyne (*.mem)</translation>
+        <translation type="unfinished">Bases de datos Mnemosyne (*.mem)</translation>
     </message>
     <message>
         <source>Please wait...</source>
-        <translation>Por favor espere...</translation>
+        <translation type="unfinished">Por favor espere...</translation>
     </message>
     <message>
         <source>Mnemosyne</source>
-        <translation>Mnemosyne</translation>
+        <translation type="unfinished">Mnemosyne</translation>
     </message>
     <message>
         <source>Delete current card?</source>
-        <translation>¿Desechar esta tarjeta?</translation>
+        <translation type="unfinished">¿Desechar esta tarjeta?</translation>
     </message>
     <message>
         <source>&amp;Yes</source>
-        <translation>&amp;Sí</translation>
+        <translation type="unfinished">&amp;Sí</translation>
     </message>
     <message>
         <source>&amp;No</source>
-        <translation>&amp;No</translation>
+        <translation type="unfinished">&amp;No</translation>
     </message>
     <message>
         <source>Returns in </source>
-        <translation>Volverá a aparecer en </translation>
+        <translation type="unfinished">Volverá a aparecer en </translation>
     </message>
     <message>
         <source> day(s).</source>
-        <translation> día(s).</translation>
+        <translation type="unfinished"> día(s).</translation>
     </message>
     <message>
         <source>Next repetition: today.</source>
-        <translation>Próxima repetición: hoy.</translation>
+        <translation type="unfinished">Próxima repetición: hoy.</translation>
     </message>
     <message>
         <source>Next repetition: tomorrow.</source>
-        <translation>Próxima repetición: mañana.</translation>
+        <translation type="unfinished">Próxima repetición: mañana.</translation>
     </message>
     <message>
         <source>Next repetition in </source>
-        <translation>Próxima repetición dentro de </translation>
+        <translation type="unfinished">Próxima repetición dentro de </translation>
     </message>
     <message>
         <source>Question:</source>
-        <translation>Pregunta:</translation>
+        <translation type="unfinished">Pregunta:</translation>
     </message>
     <message>
         <source>&lt;default&gt;</source>
-        <translation>&lt;por defecto&gt;</translation>
+        <translation type="unfinished">&lt;por defecto&gt;</translation>
     </message>
     <message>
         <source>Show &amp;answer</source>
@@ -927,27 +927,27 @@ Tal vez desee ejecutar </translation>
     </message>
     <message>
         <source>Learn ahead of schedule</source>
-        <translation>Aprender antes de tiempo</translation>
+        <translation type="unfinished">Aprender antes de tiempo</translation>
     </message>
     <message>
         <source>Pick days until next repetition:</source>
-        <translation>Escoger días hasta la próxima repetición:</translation>
+        <translation type="unfinished">Escoger días hasta la próxima repetición:</translation>
     </message>
     <message>
         <source>Grade your answer:</source>
-        <translation>Evalúe su respuesta:</translation>
+        <translation type="unfinished">Evalúe su respuesta:</translation>
     </message>
     <message>
         <source>Scheduled: </source>
-        <translation>Planificadas:</translation>
+        <translation type="unfinished">Planificadas:</translation>
     </message>
     <message>
         <source>Not memorised: </source>
-        <translation>No memorizadas: </translation>
+        <translation type="unfinished">No memorizadas: </translation>
     </message>
     <message>
         <source>All: </source>
-        <translation>Todas: </translation>
+        <translation type="unfinished">Todas: </translation>
     </message>
     <message>
         <source>New</source>
