@@ -82,55 +82,55 @@ Creating tmp file.</source>
     </message>
     <message>
         <source>You don&apos;t remember this card yet.</source>
-        <translation>شما هنوز این کارت را به یاد نمی‌آورید.</translation>
+        <translation type="unfinished">شما هنوز این کارت را به یاد نمی‌آورید.</translation>
     </message>
     <message>
         <source>Like &apos;0&apos;, but it&apos;s getting more familiar.</source>
-        <translation>مانند گزینه »۰«٬ اما این آشناتر به نظر می‌رسد.</translation>
+        <translation type="unfinished">مانند گزینه »۰«٬ اما این آشناتر به نظر می‌رسد.</translation>
     </message>
     <message>
         <source> Show it less often.</source>
-        <translation>آن را کمتر نشان بده.</translation>
+        <translation type="unfinished">آن را کمتر نشان بده.</translation>
     </message>
     <message>
         <source>You&apos;ve memorised this card now,</source>
-        <translation>اکنون شما این کارت را حفظ شده‌اید٬</translation>
+        <translation type="unfinished">اکنون شما این کارت را حفظ شده‌اید٬</translation>
     </message>
     <message>
         <source> and will probably remember it for a few days.</source>
-        <translation>و احتمالا آن را برای چند روز به یاد می‌آورید.</translation>
+        <translation type="unfinished">و احتمالا آن را برای چند روز به یاد می‌آورید.</translation>
     </message>
     <message>
         <source>You have forgotten this card completely.</source>
-        <translation>شما به کلی این کارت را فراموش کرده‌اید.</translation>
+        <translation type="unfinished">شما به کلی این کارت را فراموش کرده‌اید.</translation>
     </message>
     <message>
         <source>Barely correct answer. The interval was way too long.</source>
-        <translation>پاسخ صحیح اما به سختی. وقفه بسیار طولانی بود.</translation>
+        <translation type="unfinished">پاسخ صحیح اما به سختی. وقفه بسیار طولانی بود.</translation>
     </message>
     <message>
         <source>Correct answer, but with much effort.</source>
-        <translation>پاسخ صحیح٬ اما با سعی زیاد.</translation>
+        <translation type="unfinished">پاسخ صحیح٬ اما با سعی زیاد.</translation>
     </message>
     <message>
         <source> The interval was probably too long.</source>
-        <translation>وقفه احتمالا طولانی بود.</translation>
+        <translation type="unfinished">وقفه احتمالا طولانی بود.</translation>
     </message>
     <message>
         <source>Correct answer, with some effort.</source>
-        <translation>پاسخ درست٬ با تلاش اندک.</translation>
+        <translation type="unfinished">پاسخ درست٬ با تلاش اندک.</translation>
     </message>
     <message>
         <source> The interval was probably just right.</source>
-        <translation>وقفه احتمالا عادی بود.</translation>
+        <translation type="unfinished">وقفه احتمالا عادی بود.</translation>
     </message>
     <message>
         <source>Correct answer, but without any</source>
-        <translation>پاسخ صحیح و بدون هیچ</translation>
+        <translation type="unfinished">پاسخ صحیح و بدون هیچ</translation>
     </message>
     <message>
         <source> difficulties. The interval was probably too short.</source>
-        <translation>مشکلی٬ وقفه احتمالا خیلی کوتاه بود.</translation>
+        <translation type="unfinished">مشکلی٬ وقفه احتمالا خیلی کوتاه بود.</translation>
     </message>
 </context>
 <context>
@@ -857,63 +857,63 @@ so you might want to run </source>
     <name>MainDlg</name>
     <message>
         <source>Mnemosyne databases (*.mem)</source>
-        <translation>(*.mem) پایگاه داده‌های نموساین</translation>
+        <translation type="unfinished">(*.mem) پایگاه داده‌های نموساین</translation>
     </message>
     <message>
         <source>New</source>
-        <translation>جدید</translation>
+        <translation type="unfinished">جدید</translation>
     </message>
     <message>
         <source>Please wait...</source>
-        <translation>لطفا صبر کنید...</translation>
+        <translation type="unfinished">لطفا صبر کنید...</translation>
     </message>
     <message>
         <source>Mnemosyne</source>
-        <translation>نموساین</translation>
+        <translation type="unfinished">نموساین</translation>
     </message>
     <message>
         <source>Delete current card?</source>
-        <translation>کارت کنونی حذف شود؟</translation>
+        <translation type="unfinished">کارت کنونی حذف شود؟</translation>
     </message>
     <message>
         <source>&amp;Yes</source>
-        <translation>بله</translation>
+        <translation type="unfinished">بله</translation>
     </message>
     <message>
         <source>&amp;No</source>
-        <translation>خیر</translation>
+        <translation type="unfinished">خیر</translation>
     </message>
     <message>
         <source>Returns in </source>
-        <translation>بازگشت در</translation>
+        <translation type="unfinished">بازگشت در</translation>
     </message>
     <message>
         <source> day(s).</source>
-        <translation>.روز</translation>
+        <translation type="unfinished">.روز</translation>
     </message>
     <message>
         <source>Next repetition: today.</source>
-        <translation>.مرور بعدی: امروز</translation>
+        <translation type="unfinished">.مرور بعدی: امروز</translation>
     </message>
     <message>
         <source>Next repetition: tomorrow.</source>
-        <translation>.مرور بعدی: فردا</translation>
+        <translation type="unfinished">.مرور بعدی: فردا</translation>
     </message>
     <message>
         <source>Next repetition in </source>
-        <translation>مرور بعدی در</translation>
+        <translation type="unfinished">مرور بعدی در</translation>
     </message>
     <message>
         <source> days.</source>
-        <translation>روز بعد.</translation>
+        <translation type="unfinished">روز بعد.</translation>
     </message>
     <message>
         <source>Question:</source>
-        <translation>پرسش:</translation>
+        <translation type="unfinished">پرسش:</translation>
     </message>
     <message>
         <source>&lt;default&gt;</source>
-        <translation>پیش فرض:</translation>
+        <translation type="unfinished">پیش فرض:</translation>
     </message>
     <message>
         <source>Show &amp;answer</source>
@@ -921,27 +921,27 @@ so you might want to run </source>
     </message>
     <message>
         <source>Learn ahead of schedule</source>
-        <translation>یادگیری جلوتر از برنامه‌ریزی</translation>
+        <translation type="unfinished">یادگیری جلوتر از برنامه‌ریزی</translation>
     </message>
     <message>
         <source>Pick days until next repetition:</source>
-        <translation>روزهای قبل از مرور بعدی را انتخاب کنید:</translation>
+        <translation type="unfinished">روزهای قبل از مرور بعدی را انتخاب کنید:</translation>
     </message>
     <message>
         <source>Grade your answer:</source>
-        <translation>مرتبه پاسخ خود را مشخص کنید:</translation>
+        <translation type="unfinished">مرتبه پاسخ خود را مشخص کنید:</translation>
     </message>
     <message>
         <source>Scheduled: </source>
-        <translation>برنامه‌ریزی شده: </translation>
+        <translation type="unfinished">برنامه‌ریزی شده: </translation>
     </message>
     <message>
         <source>Not memorised: </source>
-        <translation>حفظ نشده‌ها: </translation>
+        <translation type="unfinished">حفظ نشده‌ها: </translation>
     </message>
     <message>
         <source>All: </source>
-        <translation>همه: </translation>
+        <translation type="unfinished">همه: </translation>
     </message>
     <message>
         <source>Show answer</source>
