@@ -85,55 +85,55 @@ Creating tmp file.</source>
     </message>
     <message>
         <source>You don&apos;t remember this card yet.</source>
-        <translation>אינכם זוכרים כרטיסיה זו עדיין.</translation>
+        <translation type="unfinished">אינכם זוכרים כרטיסיה זו עדיין.</translation>
     </message>
     <message>
         <source>Like &apos;0&apos;, but it&apos;s getting more familiar.</source>
-        <translation>כמו &apos;0&apos;, אבל נהיה מוכר יותר.</translation>
+        <translation type="unfinished">כמו &apos;0&apos;, אבל נהיה מוכר יותר.</translation>
     </message>
     <message>
         <source> Show it less often.</source>
-        <translation> הצג זאת לעתים רחוקות יותר.</translation>
+        <translation type="unfinished"> הצג זאת לעתים רחוקות יותר.</translation>
     </message>
     <message>
         <source>You&apos;ve memorised this card now,</source>
-        <translation>כעת אתם זוכרים כרטיסיה זו</translation>
+        <translation type="unfinished">כעת אתם זוכרים כרטיסיה זו</translation>
     </message>
     <message>
         <source> and will probably remember it for a few days.</source>
-        <translation> וככל הנראה תזכרו אותה במשך מספר ימים.</translation>
+        <translation type="unfinished"> וככל הנראה תזכרו אותה במשך מספר ימים.</translation>
     </message>
     <message>
         <source>You have forgotten this card completely.</source>
-        <translation>שכחתם כרטיסיה זו לחלוטין.</translation>
+        <translation type="unfinished">שכחתם כרטיסיה זו לחלוטין.</translation>
     </message>
     <message>
         <source>Barely correct answer. The interval was way too long.</source>
-        <translation>תשובה כמעט נכונה. ההשהייה בהחלט הייתה ארוכה מדי.</translation>
+        <translation type="unfinished">תשובה כמעט נכונה. ההשהייה בהחלט הייתה ארוכה מדי.</translation>
     </message>
     <message>
         <source>Correct answer, but with much effort.</source>
-        <translation>תשובה נכונה, אבל תוך מאמץ ניכר.</translation>
+        <translation type="unfinished">תשובה נכונה, אבל תוך מאמץ ניכר.</translation>
     </message>
     <message>
         <source> The interval was probably too long.</source>
-        <translation> ההשהייה כנראה הייתה ארוכה מדי.</translation>
+        <translation type="unfinished"> ההשהייה כנראה הייתה ארוכה מדי.</translation>
     </message>
     <message>
         <source>Correct answer, with some effort.</source>
-        <translation>תשובה נכונה, תוך מאמץ מסויים.</translation>
+        <translation type="unfinished">תשובה נכונה, תוך מאמץ מסויים.</translation>
     </message>
     <message>
         <source> The interval was probably just right.</source>
-        <translation> ההשהייה כנראה התאימה בדיוק.</translation>
+        <translation type="unfinished"> ההשהייה כנראה התאימה בדיוק.</translation>
     </message>
     <message>
         <source>Correct answer, but without any</source>
-        <translation>תשובה נכונה, אבל ללא כל</translation>
+        <translation type="unfinished">תשובה נכונה, אבל ללא כל</translation>
     </message>
     <message>
         <source> difficulties. The interval was probably too short.</source>
-        <translation> קושי. ההשהייה כנראה הייתה קצרה מדי.</translation>
+        <translation type="unfinished"> קושי. ההשהייה כנראה הייתה קצרה מדי.</translation>
     </message>
 </context>
 <context>
@@ -864,63 +864,63 @@ so you might want to run </source>
     <name>MainDlg</name>
     <message>
         <source>Mnemosyne databases (*.mem)</source>
-        <translation>בסיס נתונים של מנימוסינה (*.mem)</translation>
+        <translation type="unfinished">בסיס נתונים של מנימוסינה (*.mem)</translation>
     </message>
     <message>
         <source>New</source>
-        <translation>חדש</translation>
+        <translation type="unfinished">חדש</translation>
     </message>
     <message>
         <source>Please wait...</source>
-        <translation>אנא המתינו...</translation>
+        <translation type="unfinished">אנא המתינו...</translation>
     </message>
     <message>
         <source>Mnemosyne</source>
-        <translation>מנימוסינה</translation>
+        <translation type="unfinished">מנימוסינה</translation>
     </message>
     <message>
         <source>Delete current card?</source>
-        <translation>למחוק כרטיסיה נוכחית?</translation>
+        <translation type="unfinished">למחוק כרטיסיה נוכחית?</translation>
     </message>
     <message>
         <source>&amp;Yes</source>
-        <translation>&amp;כן</translation>
+        <translation type="unfinished">&amp;כן</translation>
     </message>
     <message>
         <source>&amp;No</source>
-        <translation>&amp;לא</translation>
+        <translation type="unfinished">&amp;לא</translation>
     </message>
     <message>
         <source>Returns in </source>
-        <translation>תחזור בעוד</translation>
+        <translation type="unfinished">תחזור בעוד</translation>
     </message>
     <message>
         <source> day(s).</source>
-        <translation>ימים.</translation>
+        <translation type="unfinished">ימים.</translation>
     </message>
     <message>
         <source>Next repetition: today.</source>
-        <translation>החזרה הבאה: היום.</translation>
+        <translation type="unfinished">החזרה הבאה: היום.</translation>
     </message>
     <message>
         <source>Next repetition: tomorrow.</source>
-        <translation>החזרה הבאה: מחר.</translation>
+        <translation type="unfinished">החזרה הבאה: מחר.</translation>
     </message>
     <message>
         <source>Next repetition in </source>
-        <translation>החזרה הבאה בעוד </translation>
+        <translation type="unfinished">החזרה הבאה בעוד </translation>
     </message>
     <message>
         <source> days.</source>
-        <translation> ימים.</translation>
+        <translation type="unfinished"> ימים.</translation>
     </message>
     <message>
         <source>Question:</source>
-        <translation>שאלה:</translation>
+        <translation type="unfinished">שאלה:</translation>
     </message>
     <message>
         <source>&lt;default&gt;</source>
-        <translation>&lt;ברירת מחדל&gt;</translation>
+        <translation type="unfinished">&lt;ברירת מחדל&gt;</translation>
     </message>
     <message>
         <source>Show &amp;answer</source>
@@ -928,31 +928,31 @@ so you might want to run </source>
     </message>
     <message>
         <source>Learn ahead of schedule</source>
-        <translation>להתקדם לפני התכנון</translation>
+        <translation type="unfinished">להתקדם לפני התכנון</translation>
     </message>
     <message>
         <source>Pick days until next repetition:</source>
-        <translation>בחרו מספר ימים לפני החזרה הבאה:</translation>
+        <translation type="unfinished">בחרו מספר ימים לפני החזרה הבאה:</translation>
     </message>
     <message>
         <source>Grade your answer:</source>
-        <translation>דרגו תשובתכם:</translation>
+        <translation type="unfinished">דרגו תשובתכם:</translation>
     </message>
     <message>
         <source>Scheduled: </source>
-        <translation>מתוכננות: </translation>
+        <translation type="unfinished">מתוכננות: </translation>
     </message>
     <message>
         <source>Not memorised: </source>
-        <translation>לא נלמדו: </translation>
+        <translation type="unfinished">לא נלמדו: </translation>
     </message>
     <message>
         <source>All: </source>
-        <translation>סך הכל: </translation>
+        <translation type="unfinished">סך הכל: </translation>
     </message>
     <message>
         <source>Show answer</source>
-        <translation>הצג תשובה</translation>
+        <translation type="unfinished">הצג תשובה</translation>
     </message>
 </context>
 <context>
