@@ -85,55 +85,55 @@ TMPファイルを作成しています。</translation>
     </message>
     <message>
         <source>You don&apos;t remember this card yet.</source>
-        <translation>このカードはまだ覚えっていません。</translation>
+        <translation type="unfinished">このカードはまだ覚えっていません。</translation>
     </message>
     <message>
         <source>Like &apos;0&apos;, but it&apos;s getting more familiar.</source>
-        <translation>「０」に似ているが、どんどんと慣れ親しんでいきます。</translation>
+        <translation type="unfinished">「０」に似ているが、どんどんと慣れ親しんでいきます。</translation>
     </message>
     <message>
         <source> Show it less often.</source>
-        <translation> 今からあまり見せないようにします。</translation>
+        <translation type="unfinished"> 今からあまり見せないようにします。</translation>
     </message>
     <message>
         <source>You&apos;ve memorised this card now,</source>
-        <translation>今このカードのことを記憶しましたから</translation>
+        <translation type="unfinished">今このカードのことを記憶しましたから</translation>
     </message>
     <message>
         <source> and will probably remember it for a few days.</source>
-        <translation>おそらく数日は覚えているでしょう。</translation>
+        <translation type="unfinished">おそらく数日は覚えているでしょう。</translation>
     </message>
     <message>
         <source>You have forgotten this card completely.</source>
-        <translation>このカードのことを完全に忘れてしまいました。</translation>
+        <translation type="unfinished">このカードのことを完全に忘れてしまいました。</translation>
     </message>
     <message>
         <source>Barely correct answer. The interval was way too long.</source>
-        <translation>かろうじて、正解。休止期間はあまりにも長すぎます。</translation>
+        <translation type="unfinished">かろうじて、正解。休止期間はあまりにも長すぎます。</translation>
     </message>
     <message>
         <source>Correct answer, but with much effort.</source>
-        <translation>かなりの努力をして正解。</translation>
+        <translation type="unfinished">かなりの努力をして正解。</translation>
     </message>
     <message>
         <source> The interval was probably too long.</source>
-        <translation>休止期間はおそらく長すぎます。</translation>
+        <translation type="unfinished">休止期間はおそらく長すぎます。</translation>
     </message>
     <message>
         <source>Correct answer, with some effort.</source>
-        <translation>いくつかの努力をしての正解。</translation>
+        <translation type="unfinished">いくつかの努力をしての正解。</translation>
     </message>
     <message>
         <source> The interval was probably just right.</source>
-        <translation>休止期間はおそらく正しい。</translation>
+        <translation type="unfinished">休止期間はおそらく正しい。</translation>
     </message>
     <message>
         <source>Correct answer, but without any</source>
-        <translation>何の困難も無く正解。この休止期間は</translation>
+        <translation type="unfinished">何の困難も無く正解。この休止期間は</translation>
     </message>
     <message>
         <source> difficulties. The interval was probably too short.</source>
-        <translation>おそらく短すぎます。</translation>
+        <translation type="unfinished">おそらく短すぎます。</translation>
     </message>
 </context>
 <context>
@@ -868,63 +868,63 @@ so you might want to run </source>
     <name>MainDlg</name>
     <message>
         <source>Mnemosyne databases (*.mem)</source>
-        <translation>覚エテチョウデータベース(*.mem)</translation>
+        <translation type="unfinished">覚エテチョウデータベース(*.mem)</translation>
     </message>
     <message>
         <source>New</source>
-        <translation>新しいデータベース</translation>
+        <translation type="unfinished">新しいデータベース</translation>
     </message>
     <message>
         <source>Please wait...</source>
-        <translation>少々お待ちください…</translation>
+        <translation type="unfinished">少々お待ちください…</translation>
     </message>
     <message>
         <source>Mnemosyne</source>
-        <translation>覚エテチョウ</translation>
+        <translation type="unfinished">覚エテチョウ</translation>
     </message>
     <message>
         <source>Delete current card?</source>
-        <translation>このカードを消してもよろしいですか?</translation>
+        <translation type="unfinished">このカードを消してもよろしいですか?</translation>
     </message>
     <message>
         <source>&amp;Yes</source>
-        <translation>&amp;はい</translation>
+        <translation type="unfinished">&amp;はい</translation>
     </message>
     <message>
         <source>&amp;No</source>
-        <translation>&amp;いいえ</translation>
+        <translation type="unfinished">&amp;いいえ</translation>
     </message>
     <message>
         <source>Returns in </source>
-        <translation>次は　</translation>
+        <translation type="unfinished">次は　</translation>
     </message>
     <message>
         <source> day(s).</source>
-        <translation>日の後。 </translation>
+        <translation type="unfinished">日の後。 </translation>
     </message>
     <message>
         <source>Next repetition: today.</source>
-        <translation>次：今日。</translation>
+        <translation type="unfinished">次：今日。</translation>
     </message>
     <message>
         <source>Next repetition: tomorrow.</source>
-        <translation>次：明日。</translation>
+        <translation type="unfinished">次：明日。</translation>
     </message>
     <message>
         <source>Next repetition in </source>
-        <translation>次は後</translation>
+        <translation type="unfinished">次は後</translation>
     </message>
     <message>
         <source> days.</source>
-        <translation>　日。</translation>
+        <translation type="unfinished">　日。</translation>
     </message>
     <message>
         <source>Question:</source>
-        <translation>質問:</translation>
+        <translation type="unfinished">質問:</translation>
     </message>
     <message>
         <source>&lt;default&gt;</source>
-        <translation>&lt;デフォルト&gt;</translation>
+        <translation type="unfinished">&lt;デフォルト&gt;</translation>
     </message>
     <message>
         <source>Show &amp;answer</source>
@@ -932,31 +932,31 @@ so you might want to run </source>
     </message>
     <message>
         <source>Learn ahead of schedule</source>
-        <translation>カードをスケジュールより早く復習する（おすすめではない）</translation>
+        <translation type="unfinished">カードをスケジュールより早く復習する（おすすめではない）</translation>
     </message>
     <message>
         <source>Pick days until next repetition:</source>
-        <translation>次の復習のため何日間を選びなさい:</translation>
+        <translation type="unfinished">次の復習のため何日間を選びなさい:</translation>
     </message>
     <message>
         <source>Grade your answer:</source>
-        <translation>グレード:</translation>
+        <translation type="unfinished">グレード:</translation>
     </message>
     <message>
         <source>Scheduled: </source>
-        <translation>今日のカード: </translation>
+        <translation type="unfinished">今日のカード: </translation>
     </message>
     <message>
         <source>Not memorised: </source>
-        <translation>まだ覚えっていないカード: </translation>
+        <translation type="unfinished">まだ覚えっていないカード: </translation>
     </message>
     <message>
         <source>All: </source>
-        <translation>合計:</translation>
+        <translation type="unfinished">合計:</translation>
     </message>
     <message>
         <source>Show answer</source>
-        <translation>答え表示</translation>
+        <translation type="unfinished">答え表示</translation>
     </message>
 </context>
 <context>
