@@ -86,55 +86,55 @@ Oppretter tmp fil.</translation>
     </message>
     <message>
         <source>You don&apos;t remember this card yet.</source>
-        <translation>Du har ikke memorisert dette kortet enda.</translation>
+        <translation type="unfinished">Du har ikke memorisert dette kortet enda.</translation>
     </message>
     <message>
         <source>Like &apos;0&apos;, but it&apos;s getting more familiar.</source>
-        <translation>Som &apos;0&apos;, men det begynner å bli mer kjent.</translation>
+        <translation type="unfinished">Som &apos;0&apos;, men det begynner å bli mer kjent.</translation>
     </message>
     <message>
         <source> Show it less often.</source>
-        <translation> Vis det sjeldnere.</translation>
+        <translation type="unfinished"> Vis det sjeldnere.</translation>
     </message>
     <message>
         <source>You&apos;ve memorised this card now,</source>
-        <translation>Du har memorisert dette kortet nå,</translation>
+        <translation type="unfinished">Du har memorisert dette kortet nå,</translation>
     </message>
     <message>
         <source> and will probably remember it for a few days.</source>
-        <translation> og vil sannsynligvis huske det noen dager.</translation>
+        <translation type="unfinished"> og vil sannsynligvis huske det noen dager.</translation>
     </message>
     <message>
         <source>You have forgotten this card completely.</source>
-        <translation>Du har glemt dette kortet fullstendig.</translation>
+        <translation type="unfinished">Du har glemt dette kortet fullstendig.</translation>
     </message>
     <message>
         <source>Barely correct answer. The interval was way too long.</source>
-        <translation>Såvidt riktig svar. Intervallet var antakeligvis for langt.</translation>
+        <translation type="unfinished">Såvidt riktig svar. Intervallet var antakeligvis for langt.</translation>
     </message>
     <message>
         <source>Correct answer, but with much effort.</source>
-        <translation>Riktig svar, men med store anstrengelser.</translation>
+        <translation type="unfinished">Riktig svar, men med store anstrengelser.</translation>
     </message>
     <message>
         <source> The interval was probably too long.</source>
-        <translation> Intervallet var antakeligvis for langt.</translation>
+        <translation type="unfinished"> Intervallet var antakeligvis for langt.</translation>
     </message>
     <message>
         <source>Correct answer, with some effort.</source>
-        <translation>Riktig svar, med litt vanskeligheter.</translation>
+        <translation type="unfinished">Riktig svar, med litt vanskeligheter.</translation>
     </message>
     <message>
         <source> The interval was probably just right.</source>
-        <translation>Intervallet var nok akkurat passe.</translation>
+        <translation type="unfinished">Intervallet var nok akkurat passe.</translation>
     </message>
     <message>
         <source>Correct answer, but without any</source>
-        <translation>Riktig svar, men uten vanskeligheter.</translation>
+        <translation type="unfinished">Riktig svar, men uten vanskeligheter.</translation>
     </message>
     <message>
         <source> difficulties. The interval was probably too short.</source>
-        <translation> Intervallet var antakeligvis for kort.</translation>
+        <translation type="unfinished"> Intervallet var antakeligvis for kort.</translation>
     </message>
 </context>
 <context>
@@ -857,91 +857,91 @@ så du vil kanskje kjøre</translation>
     <name>MainDlg</name>
     <message>
         <source>Mnemosyne databases (*.mem)</source>
-        <translation>Mnemosyne databaser (*.mem)</translation>
+        <translation type="unfinished">Mnemosyne databaser (*.mem)</translation>
     </message>
     <message>
         <source>New</source>
-        <translation>Ny</translation>
+        <translation type="unfinished">Ny</translation>
     </message>
     <message>
         <source>Please wait...</source>
-        <translation>Venligst vent...</translation>
+        <translation type="unfinished">Venligst vent...</translation>
     </message>
     <message>
         <source>Mnemosyne</source>
-        <translation>Mnemosyne</translation>
+        <translation type="unfinished">Mnemosyne</translation>
     </message>
     <message>
         <source>Delete current card?</source>
-        <translation>Slett dette kortet?</translation>
+        <translation type="unfinished">Slett dette kortet?</translation>
     </message>
     <message>
         <source>&amp;Yes</source>
-        <translation>&amp;Ja</translation>
+        <translation type="unfinished">&amp;Ja</translation>
     </message>
     <message>
         <source>&amp;No</source>
-        <translation>&amp;Nei</translation>
+        <translation type="unfinished">&amp;Nei</translation>
     </message>
     <message>
         <source>Returns in </source>
-        <translation>Kommer igjen om</translation>
+        <translation type="unfinished">Kommer igjen om</translation>
     </message>
     <message>
         <source> day(s).</source>
-        <translation> dag(er).</translation>
+        <translation type="unfinished"> dag(er).</translation>
     </message>
     <message>
         <source>Next repetition: today.</source>
-        <translation>Neste repetisjon: i dag.</translation>
+        <translation type="unfinished">Neste repetisjon: i dag.</translation>
     </message>
     <message>
         <source>Next repetition: tomorrow.</source>
-        <translation>Neste repetisjon: i morgen.</translation>
+        <translation type="unfinished">Neste repetisjon: i morgen.</translation>
     </message>
     <message>
         <source>Next repetition in </source>
-        <translation>Neste repetisjon om</translation>
+        <translation type="unfinished">Neste repetisjon om</translation>
     </message>
     <message>
         <source> days.</source>
-        <translation> dager.</translation>
+        <translation type="unfinished"> dager.</translation>
     </message>
     <message>
         <source>Question:</source>
-        <translation>Spørsmål:</translation>
+        <translation type="unfinished">Spørsmål:</translation>
     </message>
     <message>
         <source>&lt;default&gt;</source>
-        <translation>&lt;standard&gt;</translation>
+        <translation type="unfinished">&lt;standard&gt;</translation>
     </message>
     <message>
         <source>Show answer</source>
-        <translation>Vis svar</translation>
+        <translation type="unfinished">Vis svar</translation>
     </message>
     <message>
         <source>Learn ahead of schedule</source>
-        <translation>Lær foran tidsskjema</translation>
+        <translation type="unfinished">Lær foran tidsskjema</translation>
     </message>
     <message>
         <source>Pick days until next repetition:</source>
-        <translation>Velg antall dager til neste repitisjon:</translation>
+        <translation type="unfinished">Velg antall dager til neste repitisjon:</translation>
     </message>
     <message>
         <source>Grade your answer:</source>
-        <translation>Grader ditt svar:</translation>
+        <translation type="unfinished">Grader ditt svar:</translation>
     </message>
     <message>
         <source>Scheduled: </source>
-        <translation>Planlagte repetisjoner:</translation>
+        <translation type="unfinished">Planlagte repetisjoner:</translation>
     </message>
     <message>
         <source>Not memorised: </source>
-        <translation>Ikke memorisert:</translation>
+        <translation type="unfinished">Ikke memorisert:</translation>
     </message>
     <message>
         <source>All: </source>
-        <translation>Alle:</translation>
+        <translation type="unfinished">Alle:</translation>
     </message>
 </context>
 <context>
