@@ -874,55 +874,55 @@ dus wellicht wilt u </translation>
     <name>MainDlg</name>
     <message>
         <source>Mnemosyne databases (*.mem)</source>
-        <translation>Mnemosyne gegevensbanken (*.mem)</translation>
+        <translation type="unfinished">Mnemosyne gegevensbanken (*.mem)</translation>
     </message>
     <message>
         <source>Please wait...</source>
-        <translation>Een moment...</translation>
+        <translation type="unfinished">Een moment...</translation>
     </message>
     <message>
         <source>Mnemosyne</source>
-        <translation>Mnemosyne</translation>
+        <translation type="unfinished">Mnemosyne</translation>
     </message>
     <message>
         <source>Delete current card?</source>
-        <translation>Verwijder huidige kaart?</translation>
+        <translation type="unfinished">Verwijder huidige kaart?</translation>
     </message>
     <message>
         <source>&amp;Yes</source>
-        <translation>&amp;Ja</translation>
+        <translation type="unfinished">&amp;Ja</translation>
     </message>
     <message>
         <source>&amp;No</source>
-        <translation>&amp;Nee</translation>
+        <translation type="unfinished">&amp;Nee</translation>
     </message>
     <message>
         <source>Returns in </source>
-        <translation>Komt over </translation>
+        <translation type="unfinished">Komt over </translation>
     </message>
     <message>
         <source> day(s).</source>
-        <translation>dag(en) terug.</translation>
+        <translation type="unfinished">dag(en) terug.</translation>
     </message>
     <message>
         <source>Next repetition: today.</source>
-        <translation>Volgende bevraging: vandaag.</translation>
+        <translation type="unfinished">Volgende bevraging: vandaag.</translation>
     </message>
     <message>
         <source>Next repetition: tomorrow.</source>
-        <translation>Volgende bevraging: morgen.</translation>
+        <translation type="unfinished">Volgende bevraging: morgen.</translation>
     </message>
     <message>
         <source>Next repetition in </source>
-        <translation>Volgende bevraging over </translation>
+        <translation type="unfinished">Volgende bevraging over </translation>
     </message>
     <message>
         <source>Question:</source>
-        <translation>Vraag:</translation>
+        <translation type="unfinished">Vraag:</translation>
     </message>
     <message>
         <source>&lt;default&gt;</source>
-        <translation>&lt;standaard&gt;</translation>
+        <translation type="unfinished">&lt;standaard&gt;</translation>
     </message>
     <message>
         <source>Show &amp;answer</source>
@@ -930,31 +930,31 @@ dus wellicht wilt u </translation>
     </message>
     <message>
         <source>Learn ahead of schedule</source>
-        <translation>Leer vooruit op schema</translation>
+        <translation type="unfinished">Leer vooruit op schema</translation>
     </message>
     <message>
         <source>Pick days until next repetition:</source>
-        <translation>Aantal dagen tot volgende bevraging:</translation>
+        <translation type="unfinished">Aantal dagen tot volgende bevraging:</translation>
     </message>
     <message>
         <source>Grade your answer:</source>
-        <translation>Beoordeel uw antwoord:</translation>
+        <translation type="unfinished">Beoordeel uw antwoord:</translation>
     </message>
     <message>
         <source>Scheduled: </source>
-        <translation>Geroosterd: </translation>
+        <translation type="unfinished">Geroosterd: </translation>
     </message>
     <message>
         <source>Not memorised: </source>
-        <translation>Niet onthouden: </translation>
+        <translation type="unfinished">Niet onthouden: </translation>
     </message>
     <message>
         <source>All: </source>
-        <translation>Alle: </translation>
+        <translation type="unfinished">Alle: </translation>
     </message>
     <message>
         <source>New</source>
-        <translation>Nieuw</translation>
+        <translation type="unfinished">Nieuw</translation>
     </message>
     <message>
         <source> days.</source>
