@@ -84,55 +84,55 @@ Tworzenie pliku tymczasowego &quot;tmp&quot;.</translation>
     </message>
     <message>
         <source>You don&apos;t remember this card yet.</source>
-        <translation>Karta nie została jeszcze zapamiętana.</translation>
+        <translation type="unfinished">Karta nie została jeszcze zapamiętana.</translation>
     </message>
     <message>
         <source>Like &apos;0&apos;, but it&apos;s getting more familiar.</source>
-        <translation>Informacja znana, jednak niezapamiętana.</translation>
+        <translation type="unfinished">Informacja znana, jednak niezapamiętana.</translation>
     </message>
     <message>
         <source> Show it less often.</source>
-        <translation> Wyświetlaj rzadziej.</translation>
+        <translation type="unfinished"> Wyświetlaj rzadziej.</translation>
     </message>
     <message>
         <source>You&apos;ve memorised this card now,</source>
-        <translation>Informacja zapamiętana</translation>
+        <translation type="unfinished">Informacja zapamiętana</translation>
     </message>
     <message>
         <source> and will probably remember it for a few days.</source>
-        <translation> i pozostanie w pamięci przez około 2 dni.</translation>
+        <translation type="unfinished"> i pozostanie w pamięci przez około 2 dni.</translation>
     </message>
     <message>
         <source>You have forgotten this card completely.</source>
-        <translation>Karta niezapamiętana.</translation>
+        <translation type="unfinished">Karta niezapamiętana.</translation>
     </message>
     <message>
         <source>Barely correct answer. The interval was way too long.</source>
-        <translation>Odpowiedź zawierała błędy. Przerwa między powtórkami była zbyt długa.</translation>
+        <translation type="unfinished">Odpowiedź zawierała błędy. Przerwa między powtórkami była zbyt długa.</translation>
     </message>
     <message>
         <source>Correct answer, but with much effort.</source>
-        <translation>Poprawna odpowiedź udzielona z wielkim wysiłkiem.</translation>
+        <translation type="unfinished">Poprawna odpowiedź udzielona z wielkim wysiłkiem.</translation>
     </message>
     <message>
         <source> The interval was probably too long.</source>
-        <translation> Przerwa między powtórkami była zbyt długa.</translation>
+        <translation type="unfinished"> Przerwa między powtórkami była zbyt długa.</translation>
     </message>
     <message>
         <source>Correct answer, with some effort.</source>
-        <translation>Poprawna odpowiedź udzielona bez znaczącego wysiłku.</translation>
+        <translation type="unfinished">Poprawna odpowiedź udzielona bez znaczącego wysiłku.</translation>
     </message>
     <message>
         <source> The interval was probably just right.</source>
-        <translation> Przerwa między powtórkami jest odpowiednia.</translation>
+        <translation type="unfinished"> Przerwa między powtórkami jest odpowiednia.</translation>
     </message>
     <message>
         <source>Correct answer, but without any</source>
-        <translation>Poprawna odpowiedź udzielona</translation>
+        <translation type="unfinished">Poprawna odpowiedź udzielona</translation>
     </message>
     <message>
         <source> difficulties. The interval was probably too short.</source>
-        <translation> z łatwością. Przerwa między powtórkami była zbyt krótka.</translation>
+        <translation type="unfinished"> z łatwością. Przerwa między powtórkami była zbyt krótka.</translation>
     </message>
 </context>
 <context>
@@ -500,7 +500,7 @@ Tworzenie pliku tymczasowego &quot;tmp&quot;.</translation>
     </message>
     <message>
         <source>Number of grade 0 cards to learn at once:</source>
-        <translation>Ilość przeznaczonych do zapamiętania kart, które otrzymały ocenę 0:</translation>
+        <translation type="obsolete">Ilość przeznaczonych do zapamiętania kart, które otrzymały ocenę 0:</translation>
     </message>
     <message>
         <source>Note: this is NOT the number of grade 0 cards you want to memorise *per day*</source>
@@ -522,6 +522,10 @@ Tworzenie pliku tymczasowego &quot;tmp&quot;.</translation>
         <source>Learn new cards in random order</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Number of grade 0 cards to hold in your hand:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditItemFrm</name>
@@ -862,63 +866,63 @@ Konieczne może być</translation>
     <name>MainDlg</name>
     <message>
         <source>Mnemosyne databases (*.mem)</source>
-        <translation>baza danych programu Mnemosyne (*.mem)</translation>
+        <translation type="unfinished">baza danych programu Mnemosyne (*.mem)</translation>
     </message>
     <message>
         <source>New</source>
-        <translation>Nowy</translation>
+        <translation type="unfinished">Nowy</translation>
     </message>
     <message>
         <source>Please wait...</source>
-        <translation>Proszę czekać...</translation>
+        <translation type="unfinished">Proszę czekać...</translation>
     </message>
     <message>
         <source>Mnemosyne</source>
-        <translation>Mnemosyne</translation>
+        <translation type="unfinished">Mnemosyne</translation>
     </message>
     <message>
         <source>Delete current card?</source>
-        <translation>Czy na pewno chcesz usunąć zaznaczoną kartę?</translation>
+        <translation type="unfinished">Czy na pewno chcesz usunąć zaznaczoną kartę?</translation>
     </message>
     <message>
         <source>&amp;Yes</source>
-        <translation>&amp;Tak</translation>
+        <translation type="unfinished">&amp;Tak</translation>
     </message>
     <message>
         <source>&amp;No</source>
-        <translation>&amp;Nie</translation>
+        <translation type="unfinished">&amp;Nie</translation>
     </message>
     <message>
         <source>Returns in </source>
-        <translation>Karta zostanie wyświetlona ponownie w ciągu</translation>
+        <translation type="unfinished">Karta zostanie wyświetlona ponownie w ciągu</translation>
     </message>
     <message>
         <source> day(s).</source>
-        <translation> dni(a).</translation>
+        <translation type="unfinished"> dni(a).</translation>
     </message>
     <message>
         <source>Next repetition: today.</source>
-        <translation>Kolejna powtórka: dzisiaj.</translation>
+        <translation type="unfinished">Kolejna powtórka: dzisiaj.</translation>
     </message>
     <message>
         <source>Next repetition: tomorrow.</source>
-        <translation>Kolejna powtórka: jutro.</translation>
+        <translation type="unfinished">Kolejna powtórka: jutro.</translation>
     </message>
     <message>
         <source>Next repetition in </source>
-        <translation>Kolejna powtórka za najbliższe</translation>
+        <translation type="unfinished">Kolejna powtórka za najbliższe</translation>
     </message>
     <message>
         <source> days.</source>
-        <translation> dni.</translation>
+        <translation type="unfinished"> dni.</translation>
     </message>
     <message>
         <source>Question:</source>
-        <translation>Pytanie z kategorii:</translation>
+        <translation type="unfinished">Pytanie z kategorii:</translation>
     </message>
     <message>
         <source>&lt;default&gt;</source>
-        <translation>&lt;domyślny&gt;</translation>
+        <translation type="unfinished">&lt;domyślny&gt;</translation>
     </message>
     <message>
         <source>Show &amp;answer</source>
@@ -926,27 +930,27 @@ Konieczne może być</translation>
     </message>
     <message>
         <source>Learn ahead of schedule</source>
-        <translation>Nauka przed wyznaczonym czasem</translation>
+        <translation type="unfinished">Nauka przed wyznaczonym czasem</translation>
     </message>
     <message>
         <source>Pick days until next repetition:</source>
-        <translation>Wybierz liczbę dni pozostałych do następnej powtórki:</translation>
+        <translation type="unfinished">Wybierz liczbę dni pozostałych do następnej powtórki:</translation>
     </message>
     <message>
         <source>Grade your answer:</source>
-        <translation>Oceń odpowiedź:</translation>
+        <translation type="unfinished">Oceń odpowiedź:</translation>
     </message>
     <message>
         <source>Scheduled: </source>
-        <translation>Zaplanowanych:</translation>
+        <translation type="unfinished">Zaplanowanych:</translation>
     </message>
     <message>
         <source>Not memorised: </source>
-        <translation>Niezapamiętanych:</translation>
+        <translation type="unfinished">Niezapamiętanych:</translation>
     </message>
     <message>
         <source>All: </source>
-        <translation>Wszystkich: </translation>
+        <translation type="unfinished">Wszystkich: </translation>
     </message>
     <message>
         <source>Show answer</source>
@@ -1418,7 +1422,7 @@ Przyjemnej nauki!</translation>
         <source>Scheduled cards for the next days:
 
 </source>
-        <translation>Ilość kart przeznaczonych do powtórki:
+        <translation type="obsolete">Ilość kart przeznaczonych do powtórki:
 
 </translation>
     </message>
@@ -1470,6 +1474,12 @@ Przyjemnej nauki!</translation>
         <source>Days until next repetition:</source>
         <translation type="unfinished">Liczba dni pozostałych do rozpoczęcia powtórki:</translation>
     </message>
+    <message>
+        <source>Scheduled cards for next week:
+
+</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>StatisticsFrm</name>
