@@ -494,7 +494,7 @@ Criando arquivo temporário.</translation>
     </message>
     <message>
         <source>Number of grade 0 cards to learn at once:</source>
-        <translation type="unfinished">Número de cartões nível 0 para aprender simultaneamente:</translation>
+        <translation type="obsolete">Número de cartões nível 0 para aprender simultaneamente:</translation>
     </message>
     <message>
         <source>Note: this is NOT the number of grade 0 cards you want to memorise *per day*</source>
@@ -516,6 +516,10 @@ Criando arquivo temporário.</translation>
         <source>Learn new cards in random order</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Number of grade 0 cards to hold in your hand:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditItemFrm</name>
@@ -1406,7 +1410,7 @@ Boa aprendizagem!</translation>
         <source>Scheduled cards for the next days:
 
 </source>
-        <translation type="unfinished">Cartões agendados para os próximos dias:
+        <translation type="obsolete">Cartões agendados para os próximos dias:
 
 </translation>
     </message>
@@ -1458,6 +1462,12 @@ Boa aprendizagem!</translation>
         <source>Days until next repetition:</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Scheduled cards for next week:
+
+</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>StatisticsFrm</name>
