@@ -165,7 +165,7 @@ class MainDlg(MainFrm):
 
         pause_thinking()
 
-        out = unicode(QFileDialog.getSaveFileName(basedir,
+        out = unicode(QFileDialog.getSaveFileName(get_basedir(),
                  self.trUtf8("Mnemosyne databases (*.mem)"), self, None,\
                  self.trUtf8("New")))
         if out != "":
@@ -393,7 +393,7 @@ class MainDlg(MainFrm):
     def showStatistics(self):
         
         pause_thinking()
-        dlg = StatisticsDlg(self)
+        dlg = StatisticsDlg(self.item, self)
         dlg.exec_loop()
         unpause_thinking()
         
@@ -565,7 +565,7 @@ class MainDlg(MainFrm):
             self.item = get_new_question(learn_ahead)
             if self.item != None:
                 self.state = "SELECT SHOW"
-                self.style = card_props(preprocess(self.item.q))
+                self.style = card_props(self.item.filtered_q())
             else:
                 self.state = "SELECT AHEAD"
                 self.style = card_props("")
@@ -712,7 +712,7 @@ class MainDlg(MainFrm):
         
         question_label_text = self.trUtf8("Question:")
         if self.item!=None and self.item.cat.name!=self.trUtf8("<default>"):
-            question_label_text += " " + preprocess(self.item.cat.name)
+            question_label_text += " " + self.item.cat.name
         self.question_label.setText(question_label_text)
 
         # Update question content.
@@ -720,7 +720,7 @@ class MainDlg(MainFrm):
         if self.item == None:
             self.question.setText("")
         else:
-            text = preprocess(self.item.q)
+            text = self.item.filtered_q()
 
             if self.q_sound_played == False:
                 play_sound(text)
@@ -736,7 +736,7 @@ class MainDlg(MainFrm):
         if self.item == None or self.state == "SELECT SHOW":
             self.answer.setText("")
         else:
-            text = preprocess(self.item.a)
+            text = self.item.filtered_a()
 
             if self.a_sound_played == False:
                 play_sound(text)
@@ -749,13 +749,13 @@ class MainDlg(MainFrm):
         # Update 'show answer' button.
         
         if self.state == "EMPTY":
-            show_enabled, default, text = 0, 1, self.trUtf8("Show &answer")
+            show_enabled, default, text = 0, 1, self.trUtf8("Show answer")
             grades_enabled = 0
         elif self.state == "SELECT SHOW":
-            show_enabled, default, text = 1, 1, self.trUtf8("Show &answer")
+            show_enabled, default, text = 1, 1, self.trUtf8("Show answer")
             grades_enabled = 0
         elif self.state == "SELECT GRADE":
-            show_enabled, default, text = 0, 1, self.trUtf8("Show &answer")
+            show_enabled, default, text = 0, 1, self.trUtf8("Show answer")
             grades_enabled = 1
         elif self.state == "SELECT AHEAD":
             show_enabled, default, text = 1, 0, \
@@ -826,6 +826,6 @@ class MainDlg(MainFrm):
     ##########################################################################
 
     def replaySound(self):
-        play_sound(preprocess(self.item.q))
+        play_sound(self.item.filtered_q())
         if self.state == "SELECT GRADE":
-            play_sound(preprocess(self.item.a))
+            play_sound(self.item.filtered_a())
